@@ -25,12 +25,12 @@
 #include <QAbstractListModel>
 
 #include "maps.h"
-#include "ref.h"
 
 namespace QPulseAudio
 {
+    class Context;
 
-class Q_DECL_EXPORT AbstractModel : public QAbstractListModel, public Ref
+class AbstractModel : public QAbstractListModel
 {
     Q_OBJECT
 public:
@@ -48,6 +48,7 @@ public:
 protected:
     AbstractModel(const MapBaseQObject *map, QObject *parent);
     void initRoleNames(const QMetaObject &qobjectMetaObject);
+    Context *context() const;
 
 private slots:
     void propertyChanged();
@@ -68,14 +69,14 @@ private:
     AbstractModel() {}
 };
 
-class Q_DECL_EXPORT CardModel : public AbstractModel
+class CardModel : public AbstractModel
 {
     Q_OBJECT
 public:
     CardModel(QObject *parent = nullptr);
 };
 
-class Q_DECL_EXPORT SinkModel : public AbstractModel
+class SinkModel : public AbstractModel
 {
     Q_OBJECT
     Q_PROPERTY(QPulseAudio::Sink *defaultSink READ defaultSink NOTIFY defaultSinkChanged)
@@ -104,14 +105,14 @@ private:
     Sink *m_preferredSink;
 };
 
-class Q_DECL_EXPORT SinkInputModel : public AbstractModel
+class SinkInputModel : public AbstractModel
 {
     Q_OBJECT
 public:
     SinkInputModel(QObject *parent = nullptr);
 };
 
-class Q_DECL_EXPORT SourceModel : public AbstractModel
+class SourceModel : public AbstractModel
 {
     Q_OBJECT
     Q_PROPERTY(QPulseAudio::Source *defaultSource READ defaultSource NOTIFY defaultSourceChanged)
@@ -129,20 +130,27 @@ signals:
     void defaultSourceChanged();
 };
 
-class Q_DECL_EXPORT SourceOutputModel : public AbstractModel
+class SourceOutputModel : public AbstractModel
 {
     Q_OBJECT
 public:
     SourceOutputModel(QObject *parent = nullptr);
 };
 
-class Q_DECL_EXPORT StreamRestoreModel : public AbstractModel
+class StreamRestoreModel : public AbstractModel
 {
     Q_OBJECT
 public:
     StreamRestoreModel(QObject *parent = nullptr);
 };
 
+class ModuleModel : public AbstractModel
+{
+    Q_OBJECT
+public:
+    ModuleModel(QObject *parent = nullptr);
+};
+
 } // QPulseAudio
 
 #endif // PULSEAUDIO_H
